@@ -1,4 +1,4 @@
-/****************************************************************************
+﻿/****************************************************************************
 **
 ** Copyright (C) 2017 Denis Shienkov <denis.shienkov@gmail.com>
 ** Copyright (C) 2017 The Qt Company Ltd.
@@ -151,11 +151,11 @@ QList<QCanBusDeviceInfo> PeakCanBackend::interfaces()
 }
 
 #if defined(Q_OS_WIN32)
-class PeakCanReadNotifier : public QWinEventNotifier
+class ReadNotifier : public QWinEventNotifier
 {
     // no Q_OBJECT macro!
 public:
-    explicit PeakCanReadNotifier(PeakCanBackendPrivate *d, QObject *parent)
+    explicit ReadNotifier(PeakCanBackendPrivate *d, QObject *parent)
         : QWinEventNotifier(parent)
         , dptr(d)
     {
@@ -176,11 +176,11 @@ private:
     PeakCanBackendPrivate * const dptr;
 };
 #else
-class PeakCanReadNotifier : public QSocketNotifier
+class ReadNotifier : public QSocketNotifier
 {
     // no Q_OBJECT macro!
 public:
-    explicit PeakCanReadNotifier(PeakCanBackendPrivate *d, QObject *parent)
+    explicit ReadNotifier(PeakCanBackendPrivate *d, QObject *parent)
         : QSocketNotifier(d->readHandle, QSocketNotifier::Read, parent)
         , dptr(d)
     {
@@ -201,11 +201,11 @@ private:
 };
 #endif
 
-class PeakCanWriteNotifier : public QTimer
+class WriteNotifier : public QTimer
 {
     // no Q_OBJECT macro!
 public:
-    PeakCanWriteNotifier(PeakCanBackendPrivate *d, QObject *parent)
+    WriteNotifier(PeakCanBackendPrivate *d, QObject *parent)
         : QTimer(parent)
         , dptr(d)
     {
@@ -358,10 +358,10 @@ bool PeakCanBackendPrivate::open()
     }
 #endif
 
-    writeNotifier = new PeakCanWriteNotifier(this, q);
+    writeNotifier = new WriteNotifier(this, q);
     writeNotifier->setInterval(0);
 
-    readNotifier = new PeakCanReadNotifier(this, q);
+    readNotifier = new ReadNotifier(this, q);
     readNotifier->setEnabled(true);
 
     isOpen = true;
